==> zio-aws-textract_2.12-5.17.104.8-sources.jar: zio/aws/textract/model/HumanLoopDataAttributes.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class HumanLoopDataAttributes(
    contentClassifiers: Option[
      Iterable[zio.aws.textract.model.ContentClassifier]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes = {
    import HumanLoopDataAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
      .builder()
      .optionallyWith(
        contentClassifiers.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.contentClassifiersWithStrings)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.HumanLoopDataAttributes.ReadOnly =
    zio.aws.textract.model.HumanLoopDataAttributes.wrap(buildAwsValue())
}
object HumanLoopDataAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.HumanLoopDataAttributes =
      zio.aws.textract.model
        .HumanLoopDataAttributes(contentClassifiers.map(value => value))
    def contentClassifiers
        : Option[List[zio.aws.textract.model.ContentClassifier]]
    def getContentClassifiers
        : ZIO[Any, AwsError, List[zio.aws.textract.model.ContentClassifier]] =
      AwsError.unwrapOptionField("contentClassifiers", contentClassifiers)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
  ) extends zio.aws.textract.model.HumanLoopDataAttributes.ReadOnly {
    override val contentClassifiers
        : Option[List[zio.aws.textract.model.ContentClassifier]] = scala
      .Option(impl.contentClassifiers())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.textract.model.ContentClassifier.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
  ): zio.aws.textract.model.HumanLoopDataAttributes.ReadOnly = new Wrapper(impl)
}

==> zio-aws-textract_2.12-5.17.204.1-sources.jar: zio/aws/textract/model/HumanLoopDataAttributes.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class HumanLoopDataAttributes(
    contentClassifiers: Optional[
      Iterable[zio.aws.textract.model.ContentClassifier]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes = {
    import HumanLoopDataAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
      .builder()
      .optionallyWith(
        contentClassifiers.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.contentClassifiersWithStrings)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.HumanLoopDataAttributes.ReadOnly =
    zio.aws.textract.model.HumanLoopDataAttributes.wrap(buildAwsValue())
}
object HumanLoopDataAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.HumanLoopDataAttributes =
      zio.aws.textract.model
        .HumanLoopDataAttributes(contentClassifiers.map(value => value))
    def contentClassifiers
        : Optional[List[zio.aws.textract.model.ContentClassifier]]
    def getContentClassifiers
        : ZIO[Any, AwsError, List[zio.aws.textract.model.ContentClassifier]] =
      AwsError.unwrapOptionField("contentClassifiers", contentClassifiers)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
  ) extends zio.aws.textract.model.HumanLoopDataAttributes.ReadOnly {
    override val contentClassifiers
        : Optional[List[zio.aws.textract.model.ContentClassifier]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.contentClassifiers())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.textract.model.ContentClassifier.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.HumanLoopDataAttributes
  ): zio.aws.textract.model.HumanLoopDataAttributes.ReadOnly = new Wrapper(impl)
}
